import { Component, OnInit } from '@angular/core';
import {ActivatedRoute, Router} from '@angular/router';
import { Boilerplate } from 'src/app/models/boilerplate.model';
import { BoilerplateService } from 'src/app/services/boilerplate.service';
import { NotifierService } from "angular-notifier";


@Component({
  selector: 'app-add-boilerplate',
  templateUrl: './add-boilerplate.component.html',
  styleUrls: ['./add-boilerplate.component.scss']
})
export class AddBoilerplateComponent implements OnInit {
  boilerplate: Boilerplate = {
    group_of_boilerplate: this.route.snapshot.params.gb,
    title: "",
    has_prefix: false,
    has_main: false,
    has_suffix: false
  };
  submitted = false;
  private readonly notifier: NotifierService;

  constructor(private boilerplatelService: BoilerplateService, private route: ActivatedRoute,
    private router: Router, notifierService: NotifierService) {
    this.notifier = notifierService;
   }

  ngOnInit(): void {
  }

  saveBoilerplate(): void {
    const data = {
      group_of_boilerplate: this.route.snapshot.params.gb,
      title: this.boilerplate.title,
      has_prefix: this.boilerplate.has_prefix,
      has_main: this.boilerplate.has_main,
      has_suffix: this.boilerplate.has_suffix
    };

    this.boilerplatelService.create(this.route.snapshot.params.gb, data)
      .subscribe(
        response => {
          this.notifier.notify("success",(JSON.stringify(response)));
          this.submitted = true;
          this.router.navigate(['/groupboilerplates/'+this.route.snapshot.params.gb+'/boilerplates']);
        },
        error => {
          console.log(error);
          //error, warning, success, info, default
          this.notifier.notify("warning",(JSON.stringify(error["error"]["title"][0])));
        });
  }

  newBoilerplate(): void {
    this.submitted = false;
    this.boilerplate = {
      group_of_boilerplate: this.route.snapshot.params.gb,
      title: "",
      has_prefix: false,
      has_main: false,
      has_suffix: false
    };
  }

}
