import { Component, OnInit, ViewChild } from '@angular/core';
import { Boilerplate } from 'src/app/models/boilerplate.model';
import { BoilerplateData } from 'src/app/models/boilerplate.model';
import { InferenceResults } from 'src/app/models/boilerplate.model';
import { BoilerplateService } from 'src/app/services/boilerplate.service';
import { PrefixService } from 'src/app/services/prefix.service';
import { ActivatedRoute, Router } from '@angular/router';
import {MatTableDataSource} from '@angular/material/table';
import {MatPaginator} from '@angular/material/paginator';



@Component({
  selector: 'app-boilerplate-list',
  templateUrl: './boilerplate-list.component.html',
  styleUrls: ['./boilerplate-list.component.scss']
})


export class BoilerplateListComponent implements OnInit {
  
  boilerplates?: Boilerplate[];
  boilerplatesdata?: BoilerplateData[];
  currentBoilerplate?: Boilerplate;
  currentBoilerplatedata?: BoilerplateData;
  currentInfer?: InferenceResults = {
    infer_group_of_boilerplate: "",
    inference_data: "",
  }
  currentIndex = -1;
  title = '';
  displayedColumns: string[] = ['id', 'title', 'has_prefix', 'has_main', 'has_suffix', 'action'];
  newdisplayedColumns: string[] = ['id','title_data' ,'prefix_data', 'main_data', 'suffix_data', 'action'];
  dataSource :Boilerplate[] = [{}];
  thenewdataSource:BoilerplateData[] = [{}];
  newdataSource = new MatTableDataSource(this.thenewdataSource);
  infer:InferenceResults[] = [{}];

  @ViewChild(MatPaginator) paginator= this.newdataSource.paginator;


  dataofboilerplates: any [] = [];
  aprefix: any [] = [];
  main: any;
  suffix: any;
  
  constructor(private boilerplateService: BoilerplateService, private prefixService: PrefixService, private route: ActivatedRoute,
    private router: Router) { }

  ngOnInit(): void {
    this.retrieveBoilerplates();
    this.retrieve();
    this.getInfer()
  }

  retrieveBoilerplates(): void {
    this.boilerplateService.getAll(this.route.snapshot.params.gb)
      .subscribe(
        data => {
          this.boilerplates = data;
          this.dataSource = data;
        },
        error => {
          console.log(error);
        });

  }


  retrieve(): void {
    this.boilerplateService.getAllData(this.route.snapshot.params.gb)
      .subscribe(
        data => {
          this.boilerplatesdata =data;
          this.thenewdataSource = data;
          this.newdataSource = new MatTableDataSource(this.thenewdataSource);
          this.newdataSource.paginator = this.paginator;
          console.log(data)
        },
        error => {
          console.log(error);
        });

  }

  refreshList(): void {
    this.retrieveBoilerplates();
    this.currentBoilerplate = undefined;
    this.currentIndex = -1;
  }

  setActiveBoilerplate(boilerplate: Boilerplate, index: number): void {
    this.currentBoilerplate = boilerplate;
    this.currentIndex = index;
  }


  SearchTitle(): void {
    if (this.title != ''){
      this.boilerplateService.findByTitle(this.route.snapshot.params.gb, this.title)
        .subscribe(
          data => {
            this.boilerplates = data;
            this.dataSource = data;
            console.log(data);
          },
          error => {
            console.log(error);
          });

  } 
    else {
      this.retrieveBoilerplates();
    }
  }
  GetRoute(): void {
    this.router.navigate(['/groupboilerplates/'+ this.route.snapshot.params.gb +'/boilerplates/add-boilerplate'])
  }
  GetRoutedit(id: any): void {
    this.router.navigate(['/groupboilerplates/'+ this.route.snapshot.params.gb +'/boilerplates'+ id])
  }

  getInfer(): void{
    this.boilerplateService.getAllInfer(this.route.snapshot.params.gb)
    .subscribe(
      data => {
        this.currentInfer = data[0];
        this.infer = data;
        console.log(data[0]);
      },
      error => {
        console.log(error);
      });

  }

  updateInfer(id: any): void {
    this.boilerplateService.inferUpdate(this.route.snapshot.params.gb, id, this.currentInfer)
    .subscribe(
      data => {
        console.log(data);
      },
      error => {
        console.log(error);
      });
  }

  applyFilter(event: Event) {
    const filterValue = (event.target as HTMLInputElement).value;
    this.newdataSource.filter = filterValue.trim().toLowerCase();
  }

}
